/*
    Copyright (C) 2009-2010 ProFUSION embedded systems
    Copyright (C) 2009-2010 Samsung Electronics

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.
*/

/**
 * @file    ewk_main.h
 * @brief   The main file of WebKit-EFL, not tied to any view object.
 */

#ifndef ewk_main_h
#define ewk_main_h

#include "ewk_certificate.h"
#include <Eina.h>

#ifdef __cplusplus
extern "C" {
#endif

/**
 * Initializes webkit's instance.
 *
 * - initializes components needed by Efl,
 * - sets web database location,
 * - sets page cache capacity,
 * - increases a reference count of webkit's instance.
 *
 * @return a reference count of webkit's instance on success or 0 on failure
 */
EAPI int ewk_init(void);

/**
 * Decreases a reference count of webkit's instance, possibly destroying it.
 *
 * If the reference count reaches 0 webkit's instance is destroyed.
 *
 * @return a reference count of webkit's instance
 */
EAPI int ewk_shutdown(void);

/* #if ENABLE(TIZEN_NETWORK_SIGNAL) */
/**
 * callback function for receiving network events
 * @param signal kind of network event, in case of DNET it is of type NetEvent_t
 * @param device information about device which send network event, in case of DNET it is of type NetProfileType_t
 *               if device value is -1, it means that we failed with reading device information 
 */
typedef void (*ewk_network_signal_callback)(int signal, int device);

/**
 * Allows to set callback function to receive network events.
 */
EAPI void ewk_set_network_signal_callback(ewk_network_signal_callback callback, const void* data);
/* #endif TIZEN_NETWORK_SIGNAL*/

/* #if ENABLE(TIZEN_CERTIFICATE_HANDLING) */

EINA_DEPRECATED EAPI void ewk_set_certificate_confirmation_callback(ewk_certificate_confirmation_callback);

/**
 * Sets crt file basing on this file certificate validation will be done
 * @file crt file containing one or more trusted certificates, 
 * e.g /usr/lib/ssl/certs/ca-certificates.crt
 */
EINA_DEPRECATED EAPI void ewk_set_certificate_file(const char* file);
/* #endif TIZEN_CERTIFICATE_HANDLING */

/**
 * Verifies if the specified text encoding is supported by WebKit
 * 
 * @return EINA_TRUE if the specified encoding is valid, EINA_FALSE otherwise.
 */
/* if ENABLE(TIZEN_TEXT_ENCODING) */
EAPI Eina_Bool ewk_text_encoding_is_valid(const char* name);
/* #endif */

/* #if ENABLE(TIZEN_PASTEBOARD_TEXT) */
EINA_DEPRECATED EAPI void ewk_general_pasteboard_data_set(const char *data);
EINA_DEPRECATED EAPI const char *ewk_general_pasteboard_data_get(void);
/* #endif */

#ifdef __cplusplus
}
#endif
#endif // ewk_main_h
